[Bf-blender-cvs] [4f47a8b] gooseberry: Quick test to figure out performance bottleneck in gooseberry.

Antony Riakiotakis noreply at git.blender.org
Thu Jan 29 12:53:19 CET 2015


Commit: 4f47a8b240c49e7096b5f858915ccf2088fb142a
Author: Antony Riakiotakis
Date:   Thu Jan 29 12:53:06 2015 +0100
Branches: gooseberry
https://developer.blender.org/rB4f47a8b240c49e7096b5f858915ccf2088fb142a

Quick test to figure out performance bottleneck in gooseberry.

Failed proxies will now attempt to fetch a smaller proxy first before
fetching the full resolution. This might allow us to see if we are
hitting a bandwidth issue (due to high res) or a file query issue (due
to more file queries)

===================================================================

M	source/blender/blenkernel/intern/sequencer.c

===================================================================

diff --git a/source/blender/blenkernel/intern/sequencer.c b/source/blender/blenkernel/intern/sequencer.c
index dd5b676..6cb3577 100644
--- a/source/blender/blenkernel/intern/sequencer.c
+++ b/source/blender/blenkernel/intern/sequencer.c
@@ -2856,11 +2856,15 @@ static ImBuf *do_render_strip_uncached(const SeqRenderData *context, Sequence *s
 				                         seq->strip->proxy ? seq->strip->proxy->tc : IMB_TC_RECORD_RUN,
 				                         proxy_size);
 
 				/* fetching for requested proxy sze failed, try fetching the original isntead */
 				if (!ibuf && proxy_size != IMB_PROXY_NONE) {
+					IMB_Proxy_Size proxy_sizes = IMB_anim_proxy_get_existing(seq->anim);
+					while (!(proxy_size & proxy_sizes) && proxy_size > 0) {
+						proxy_size <<= 1;
+					}
 					ibuf = IMB_anim_absolute(seq->anim, nr + seq->anim_startofs,
 					                         seq->strip->proxy ? seq->strip->proxy->tc : IMB_TC_RECORD_RUN,
-					                         IMB_PROXY_NONE);
+					                         proxy_size);
 				}
 				if (ibuf) {
 					BKE_sequencer_imbuf_to_sequencer_space(context->scene, ibuf, false);
@@ -2856,11 +2856,15 @@ static ImBuf *do_render_strip_uncached(const SeqRenderData *context, Sequence *s
 				                         proxy_size);
 
-				/* fetching for requested proxy sze failed, try fetching the original isntead */
+				/* fetching for requested proxy size failed, try fetching the original instead */
 				if (!ibuf && proxy_size != IMB_PROXY_NONE) {




More information about the Bf-blender-cvs mailing list